@@ -1,7 +1,7 @@
-"""Bring many of the svg_ultralight functions into the svg_ultralight namespace.
+"""Import functions into the package namespace.
 
-:author: Shay Hill
-:created: 12/22/2019.
+:author: ShayHill
+:created: 2019-12-22
 """
 
 from svg_ultralight.bounding_boxes.bound_helpers import (
@@ -18,11 +18,13 @@ from svg_ultralight.bounding_boxes.padded_text_initializers import (
     pad_text,
     pad_text_ft,
     pad_text_mix,
+    wrap_text_ft,
 )
 from svg_ultralight.bounding_boxes.supports_bounds import SupportsBounds
 from svg_ultralight.bounding_boxes.type_bound_collection import BoundCollection
 from svg_ultralight.bounding_boxes.type_bound_element import BoundElement
 from svg_ultralight.bounding_boxes.type_bounding_box import BoundingBox
+from svg_ultralight.bounding_boxes.type_padded_list import PaddedList
 from svg_ultralight.bounding_boxes.type_padded_text import PaddedText
 from svg_ultralight.constructors.new_element import (
     deepcopy_element,
@@ -46,6 +48,7 @@ from svg_ultralight.query import (
     get_bounding_box,
     get_bounding_boxes,
 )
+from svg_ultralight.read_svg import get_bounding_box_from_root, parse
 from svg_ultralight.root_elements import new_svg_root_around_bounds
 from svg_ultralight.string_conversion import (
     format_attr_dict,
@@ -64,6 +67,7 @@ __all__ = [
     "BoundCollection",
     "BoundElement",
     "BoundingBox",
+    "PaddedList",
     "PaddedText",
     "SupportsBounds",
     "bbox_dict",
@@ -75,6 +79,7 @@ __all__ = [
     "format_number",
     "format_numbers",
     "get_bounding_box",
+    "get_bounding_box_from_root",
     "get_bounding_boxes",
     "mat_apply",
     "mat_dot",
@@ -93,9 +98,11 @@ __all__ = [
     "pad_text",
     "pad_text_ft",
     "pad_text_mix",
+    "parse",
     "parse_bound_element",
     "transform_element",
     "update_element",
+    "wrap_text_ft",
     "write_pdf",
     "write_pdf_from_svg",
     "write_png",
