@@ -7,7 +7,15 @@
 from svg_ultralight.strings.svg_strings import (
     svg_color_tuple,
     svg_float_tuples,
+    svg_floats,
     svg_ints,
+    svg_matrix,
 )
 
-__all__ = ["svg_color_tuple", "svg_float_tuples", "svg_ints"]
+__all__ = [
+    "svg_color_tuple",
+    "svg_float_tuples",
+    "svg_floats",
+    "svg_ints",
+    "svg_matrix",
+]
