@@ -9,9 +9,9 @@ from __future__ import annotations
 import numbers
 import re
 from contextlib import suppress
-from typing import TYPE_CHECKING, cast
+from typing import TYPE_CHECKING, TypeAlias, cast
 
-from svg_ultralight.string_conversion import format_number
+from svg_ultralight.strings import svg_matrix
 
 if TYPE_CHECKING:
     from lxml.etree import (
@@ -21,7 +21,7 @@ if TYPE_CHECKING:
 
 RE_MATRIX = re.compile(r"matrix\(([^)]+)\)")
 
-_Matrix = tuple[float, float, float, float, float, float]
+_Matrix: TypeAlias = tuple[float, float, float, float, float, float]
 
 
 def mat_dot(mat1: _Matrix, mat2: _Matrix) -> _Matrix:
@@ -129,13 +129,24 @@ def new_transformation_matrix(
     return mat_dot((float(scale_x), 0, 0, float(scale_y), dx, dy), transformation)
 
 
-def transform_element(elem: EtreeElement, matrix: _Matrix) -> EtreeElement:
+def transform_element(
+    elem: EtreeElement, matrix: _Matrix, *, reverse: bool = False
+) -> EtreeElement:
     """Apply a transformation matrix to an svg element.
 
     :param elem: svg element
-    :param matrix: transformation matrix
+    :par m matrix: transformation matrix
+
+    :param reverse: If you have a transformation matrix, A, and wish to apply an
+    additional transform, B, the result is B @ A. This is how an element can be
+    cumulatively transformed in svg.
+
+    If the element is transformed by A and is a part of a GROUP transformed by B,
+    then the result is the reverse: A @ B.
     """
     current = get_transform_matrix(elem)
-    updated = map(format_number, mat_dot(matrix, current))
-    elem.attrib["transform"] = f"matrix({' '.join(updated)})"
+    if reverse:
+        elem.attrib["transform"] = svg_matrix(mat_dot(current, matrix))
+    else:
+        elem.attrib["transform"] = svg_matrix(mat_dot(matrix, current))
     return elem
